use lib 't/lib';
use Test::More;
use Test::MockModule;
use strict;
use warnings;

BEGIN {
    use_ok('Test');
}

my $dezi = get_dezi_mock();
$dezi->mock( 'index', sub { 
    my $json = get_json();
    is ${$_[1]}, $json, "The first passed object is a json structure";
    is $_[2], 1, "The second passed parameter is the db id";
    is $_[3], 'application/json', "should be set to application/json";
} );

$dezi->mock( 'delete', sub { 
    is ${$_[0]}, 1;
} );

my $schema = Test->initialize;
my $resultset = $schema->resultset('Person');
my $person0 = $resultset->new({
    name        => 'FooBar',
    age         => 18,
    image_path  => './t/test_image.jpg'
});
$person0->insert;

$resultset->find_or_create({
    name        => 'FooBar',
    age         => 18,
    image_path  => './t/test_image.jpg'
});

$resultset->update({
    name        => 'BazBar',
    age         => 18,
    image_path  => './t/test_image.jpg'
});

my $results0 = $resultset->search( { name => 'BazBar' } );
is $results0->count, 1, "One record should be found";

$results0->delete;

my $results1 = $resultset->search( { name => 'BazBar' } );
is $results1->count, 0, "Zero records should be found now";

done_testing();

sub get_dezi_mock {
    my $dezi = Test::MockModule->new('Dezi::Client');
    $dezi->mock( 'new', sub { return bless {}, $_[0] } );
    return $dezi;
}

sub get_json {
return
q~{"doc":{"image_path":["image/jpeg","/9j/4AAQSkZJRgABAQEASABIAAD//gBGRmlsZSBzb3VyY2U6IGh0dHA6Ly9jb21tb25zLndpa2lt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\nkNPJJI6gWRl06r+4/wBP3wik1oHGz//Z\n"],"name":["FooBar"]}}~;

}

1;
